.. include:: ../references.txt

.. _user_guide:

==========
User guide
==========

.. toctree::
    :hidden:
    :titlesonly:

    package
    howto
    model-gallery/index
    Gammapy recipes <https://gammapy.github.io/gammapy-recipes>
    references

.. panels::
    :card: + intro-card text-center
    :column: col-lg-6 col-md-6 col-sm-6 col-xs-12 d-flex

    ---
    :img-top: ../_static/box.png

    Analysis workflow and package structure
    ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

    An overview of the main concepts in Gammapy package.

    +++

    .. link-button:: package
            :type: ref
            :text: To the package overview
            :classes: btn-block btn-secondary stretched-link


    ---
    :img-top: ../_static/index_contribute.svg

    How To
    ^^^^^^

    A short “frequently asked question” entries for Gammapy.

    +++

    .. link-button:: howto
            :type: ref
            :text: To the How To
            :classes: btn-block btn-secondary stretched-link

    ---
    :img-top: ../_static/galleryicon.png

    Model gallery
    ^^^^^^^^^^^^^

    Gammapy provides a large choice of spatial, spectral and temporal models.

    +++

    .. link-button:: model-gallery/index
            :type: ref
            :text: To the model gallery
            :classes: btn-block btn-secondary stretched-link

    ---
    :img-top: ../_static/glossaryicon.png

    Gammapy recipes
    ^^^^^^^^^^^^^^^

    A collection of **user contributed** notebooks covering aspects not present in the official tutorials.

    +++

    .. link-button:: https://gammapy.github.io/gammapy-recipes
            :type: url
            :text: To the recipes
            :classes: btn-block btn-secondary stretched-link
